@@ -50,6 +50,7 @@ EXTENSIONS = {
     'fish': {'text', 'fish'},
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
+    'geojson': {'text', 'geojson', 'json'},
     'gif': {'binary', 'image', 'gif'},
     'go': {'text', 'go'},
     'gotmpl': {'text', 'gotmpl'},
@@ -137,6 +138,7 @@ EXTENSIONS = {
     'png': {'binary', 'image', 'png'},
     'po': {'text', 'pofile'},
     'pp': {'text', 'puppet'},
+    'prisma': {'text', 'prisma'},
     'properties': {'text', 'java-properties'},
     'proto': {'text', 'proto'},
     'ps1': {'text', 'powershell'},
@@ -153,6 +155,7 @@ EXTENSIONS = {
     'r': {'text', 'r'},
     'rake': {'text', 'ruby'},
     'rb': {'text', 'ruby'},
+    'rng': {'text', 'xml', 'relax-ng'},
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
     's': {'text', 'asm'},
@@ -172,6 +175,7 @@ EXTENSIONS = {
     'ss': {'text', 'scheme'},
     'styl': {'text', 'stylus'},
     'sv': {'text', 'system-verilog'},
+    'svelte': {'text', 'svelte'},
     'svg': {'text', 'image', 'svg', 'xml'},
     'svh': {'text', 'system-verilog'},
     'swf': {'binary', 'swf'},
@@ -202,6 +206,7 @@ EXTENSIONS = {
     'vh': {'text', 'verilog'},
     'vhd': {'text', 'vhdl'},
     'vim': {'text', 'vim'},
+    'vtl': {'text', 'vtl'},
     'vue': {'text', 'vue'},
     'war': {'binary', 'zip', 'jar'},
     'wav': {'binary', 'audio', 'wav'},
